@@ -5,15 +5,16 @@ from urllib.parse import urlparse, urlunparse, urljoin
 
 import pytest
 from box import Box
+from faker import Faker
 
 from framework.exit_code import ExitCode
 from framework.db.redis_db import RedisDB
 from framework.utils.log_util import logger
 from framework.render_data import RenderData
 from framework.http_client import ResponseUtil
-from framework.utils.common import snake_to_pascal
+from framework.utils.common import snake_to_pascal, SingletonFaker
 from framework.global_attribute import CONFIG, GlobalAttribute, _FRAMEWORK_CONTEXT
-from config.settings import UNAUTHORIZED_CODE
+from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
 
 module = importlib.import_module("test_case.conftest")
 
@@ -26,6 +27,8 @@ class BaseTestCase(object):
     response: ResponseUtil = None
     context: GlobalAttribute = None
     config: GlobalAttribute = None
+    # faker方法文档 https://blog.csdn.net/m0_60052979/article/details/126368024
+    faker = SingletonFaker(locale=FAKER_LANGUAGE).faker
 
     def request(self, app=None, *, account, data, **kwargs):
         try:
