@@ -2,6 +2,7 @@ import os
 import re
 import sys
 import copy
+import threading
 import importlib
 import traceback
 from pathlib import Path
@@ -10,6 +11,7 @@ from urllib.parse import urljoin
 from collections import OrderedDict
 from datetime import datetime, timedelta
 from itertools import groupby
+
 import dill
 import retry
 import allure
@@ -172,7 +174,10 @@ def pytest_generate_tests(metafunc):
             if _mark and item.get("scenario").get("flag") != _mark:
                 continue
             deep_copied_case_data = copy.deepcopy(case_data)
+            scenario = item.get("scenario")
             try:
+                # 剔除标记disable的字段
+                deep_copied_case_data = disable_field(scenario.get("data"), deep_copied_case_data)
                 deep_copied_case_data["_scenario"] = item.get("scenario")
                 case_data_list.append(deep_copied_case_data)
                 ids.append(case_data.get("title") + f"#{index + 1}")
@@ -208,6 +213,31 @@ def pytest_collection_modifyitems(items):
             pass
 
 
+def disable_field(scenario, data):
+    def _clean(obj):
+        if isinstance(obj, dict):
+            keys_to_delete = []
+            for k, v in obj.items():
+                if isinstance(v, (dict, list)):
+                    _clean(v)
+                elif isinstance(v, str):
+                    for ak, av in scenario.items():
+                        if av == "disable" and v == f"${{{ak}}}":
+                            keys_to_delete.append(k)
+                            break
+            # 统一删除，避免边遍历边删
+            for k in keys_to_delete:
+                del obj[k]
+
+        elif isinstance(obj, list):
+            for item in obj:
+                if isinstance(item, (dict, list)):
+                    _clean(item)
+
+    _clean(data)
+    return data
+
+
 # UPDATE 将用例 按类名进行分组的核心方法
 def filtered_groupby(iterable, key_func):
     """生成器：过滤key_func返回None的元素，并按key_func分组"""
@@ -439,7 +469,7 @@ def pytest_runtest_call(item):
             # 更新记录的过期时间
             token_expiry = CONTEXT.get(_belong_app).get("token_expiry")
             expire_time = datetime.now() + timedelta(seconds=token_expiry)
-            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+            _FRAMEWORK_CONTEXT.set(app=_belong_app, key="expire_time", value=expire_time)
 
 
 def pytest_runtest_teardown(item):
@@ -551,17 +581,25 @@ class Http(object):
 
 
 def login():
+    def inner_login(app):
+        setattr(Http, app, getattr(module, f"{snake_to_pascal(app)}Login")(app))
+        token_expiry = CONTEXT.get(app).get("token_expiry")
+        if token_expiry:
+            expire_time = datetime.now() + timedelta(seconds=token_expiry)
+            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+        mysqls = CONFIG.get(app=app, key="mysql")
+        mysqls_obj = {item: MysqlDB(**mysqls.get(item)) for item in mysqls.keys()}
+        _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysqls_obj)
+
     try:
         logger.info("登录账号".center(80, "*"))
+        threads = []
         for app in all_app:
-            setattr(Http, app, getattr(module, f"{snake_to_pascal(app)}Login")(app))
-            token_expiry = CONTEXT.get(app).get("token_expiry")
-            if token_expiry:
-                expire_time = datetime.now() + timedelta(seconds=token_expiry)
-                _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
-            mysqls = CONFIG.get(app=app, key="mysql")
-            mysqls_obj = {item: MysqlDB(**mysqls.get(item)) for item in mysqls.keys()}
-            _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysqls_obj)
+            t = threading.Thread(target=inner_login, args=(app,))
+            threads.append(t)
+            t.start()
+        for t in threads:
+            t.join()
         logger.info("登录完成".center(80, "*"))
         return Http
     except Exception as e:
