@@ -6,26 +6,13 @@ import traceback
 import allure
 import pytest
 from box import Box
-from faker import Faker
 from framework.exit_code import ExitCode
 from framework.utils.log_util import logger
 from framework.global_attribute import CONTEXT
+from framework.utils.common import SingletonFaker
 from config.settings import FAKER_LANGUAGE, DATA_DIR
 
-
-class SingletonFaker(object):
-    instance = None
-    init_flag = False
-
-    def __init__(self, locale):
-        if self.init_flag:
-            return
-        self.faker = Faker(locale)
-
-    def __new__(cls, *args, **kwargs):
-        if cls.instance is None:
-            cls.instance = super().__new__(cls)
-        return cls.instance
+module = importlib.import_module("framework.utils.common")
 
 
 class RenderData(object):
@@ -46,6 +33,7 @@ class RenderData(object):
         :return:
         """
         with allure.step("渲染数据"):
+            self.replace_attribute(self.scenario)
             self.replace_attribute(self.request)
         self.data["request"] = self.request
         self.data["_is_multipart"] = self._is_multipart
@@ -113,7 +101,6 @@ class RenderData(object):
             new_expression = f"{belong_app}.{expression}"
         else:
             new_expression = expression
-
         value = (
             self.get_nested_value(self.scenario, expression)
             if self.get_nested_value(self.scenario, expression) is not None else
@@ -121,6 +108,23 @@ class RenderData(object):
             if self.get_nested_value(self.context, new_expression) is not None else
             self.get_nested_value(self.context, expression)
         )
+        # if value.endswith(")}"):
+        #     keyword = value[2:-1]
+        #     try:
+        #         pattern = re.compile(r'(?P<func_name>.+)\((?P<args>.*)\)')
+        #         match = re.match(pattern, keyword)
+        #         # 匹配方法名
+        #         func_name = match.group("func_name")
+        #         # 匹配方法位置参数
+        #         args = match.group("args")
+        #         if args:
+        #             # 将参数中字符串类型的数字转成数字类型
+        #             args = [eval(i) for i in args.replace(",", "").split(",")]
+        #             value = self.get_func_variable(keyword, func_name, *args)
+        #         else:
+        #             value = self.get_func_variable(keyword, func_name)
+        #     except Exception:
+        #         pass
 
         with allure.step(f"{expression}: {value}"):
             logger.info(f"前置读取变量: {expression}: {value}")
@@ -134,7 +138,6 @@ class RenderData(object):
         :param args:
         :return:
         """
-        module = importlib.import_module("common")
         try:
             value = getattr(module, func_name)(*args)
         except AttributeError:
